@@ -1,21 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
 /*
- * This file is part of Devhelp.
- *
- * Copyright (C) 2018 Sébastien Wilmet <swilmet@gnome.org>
- *
- * Devhelp is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published
- * by the Free Software Foundation, either version 3 of the License,
- * or (at your option) any later version.
- *
- * Devhelp is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with Devhelp.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-FileCopyrightText: 2018 Sébastien Wilmet <swilmet@gnome.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
 #include "config.h"
@@ -488,17 +474,14 @@ dh_web_view_constructed (GObject *object)
         if (G_OBJECT_CLASS (dh_web_view_parent_class)->constructed != NULL)
                 G_OBJECT_CLASS (dh_web_view_parent_class)->constructed (object);
 
-        /* Disable some things we have no need for. */
         webkit_settings = webkit_web_view_get_settings (WEBKIT_WEB_VIEW (view));
+        webkit_settings_set_enable_back_forward_navigation_gestures (webkit_settings, TRUE);
+
+        /* Disable some things we have no need for. */
         webkit_settings_set_enable_html5_database (webkit_settings, FALSE);
         webkit_settings_set_enable_html5_local_storage (webkit_settings, FALSE);
         webkit_settings_set_enable_plugins (webkit_settings, FALSE);
 
-#if WEBKIT_CHECK_VERSION(2, 23, 4)
-        /* Enable navigation gesture */
-        webkit_settings_set_enable_back_forward_navigation_gestures (webkit_settings, TRUE);
-#endif
-
         if (view->priv->profile == NULL)
                 set_profile (view, dh_profile_get_default ());
 
