@@ -1,24 +1,10 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
 /*
- * This file is part of Devhelp.
- *
- * Copyright (C) 2001-2008 Imendio AB
- * Copyright (C) 2012 Aleksander Morgado <aleksander@gnu.org>
- * Copyright (C) 2012 Thomas Bechtold <toabctl@gnome.org>
- * Copyright (C) 2015-2018 Sébastien Wilmet <swilmet@gnome.org>
- *
- * Devhelp is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published
- * by the Free Software Foundation, either version 3 of the License,
- * or (at your option) any later version.
- *
- * Devhelp is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with Devhelp.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-FileCopyrightText: 2001-2008 Imendio AB
+ * SPDX-FileCopyrightText: 2012 Aleksander Morgado <aleksander@gnu.org>
+ * SPDX-FileCopyrightText: 2012 Thomas Bechtold <toabctl@gnome.org>
+ * SPDX-FileCopyrightText: 2015-2018 Sébastien Wilmet <swilmet@gnome.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
 #include "dh-window.h"
@@ -290,6 +276,7 @@ find_cb (GSimpleAction *action,
         DhWindowPrivate *priv = dh_window_get_instance_private (window);
 
         gtk_search_bar_set_search_mode (GTK_SEARCH_BAR (priv->search_bar), TRUE);
+        dh_search_bar_grab_focus_to_search_entry (priv->search_bar);
 }
 
 static void
